<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-newmail_notifier/
*/

$labels['basic'] = 'איתות מהדפדפן על הגעת הודעות חדשות';
$labels['desktop'] = 'איתות משולחן העבודה על הגעת הודעות חדשות';
$labels['sound'] = 'השמעת איתות קולי בעת הגעה של הודעה חדשה';
$labels['test'] = 'בדיקה';
$labels['title'] = 'הודעה חדשה !';
$labels['body'] = 'התקבלה הודעה חדשה';
$labels['testbody'] = 'זה איתות לנסיון';
$labels['desktopdisabled'] = 'איתותים משולחן העבודה אינם פעילים בדפדפן שלך';
$labels['desktopunsupported'] = 'הדפדפן שלך אינו תומך באיתותים משולחן העבודה';
$labels['desktoptimeout'] = 'ביטול איתות משולחן העבודה על הגעת הודעות חדשות';
