<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'اشتراک گذاری';
$labels['username'] = 'کاربر:';
$labels['add'] = 'افزودن';
$labels['newuser'] = 'افزودن مدخل';
$labels['aclw'] = 'نوشتن نشانه ها';
$labels['aclp'] = 'ارسال';
$labels['acla'] = 'مدیر';
$labels['aclfull'] = 'کنترل کامل';
$labels['aclother'] = 'دیگر';
$labels['aclread'] = 'خواندن';
$labels['acldelete'] = 'حذف';
$labels['shortaclr'] = 'خواندن';
$labels['shortaclp'] = 'ارسال';
$labels['shortaclc'] = 'ایجاد کردن';
$labels['shortaclk'] = 'ایجاد کردن';
$labels['shortacld'] = 'حذف';
$labels['shortaclt'] = 'حذف';
$labels['shortacla'] = 'مدیر';
$labels['shortaclother'] = 'دیگر';
$labels['shortaclread'] = 'خواندن';
$labels['shortacldelete'] = 'حذف';
